<?php
/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

/*
 * Created on 28 août 07 by AEL Sarl for
 * 
 * osCommerce, Open Source E-Commerce Solutions
 * http://www.oscommerce.com
 *
 * Copyright (c) 2003 osCommerce
 *
 * Released under the GNU General Public License
 * 
 */

/**
 * Get the tax rate knowing the tax class id.
 * 
 * @param	int		$class_id	an OsCommerce tax_class_id
 * @return	double	a tax rate, or 0 if not found
 */
function opensi_get_tax_rate($class_id) {

    $tax_query = tep_db_query("SELECT SUM(tax_rate) AS tax_rate" .
                              " FROM " . TABLE_TAX_RATES . " tr" .
                              " LEFT JOIN " . TABLE_ZONES_TO_GEO_ZONES . " za" .
                              " ON (tr.tax_zone_id = za.geo_zone_id)" .
                              " LEFT JOIN " . TABLE_GEO_ZONES . " tz" .
                              " ON (tz.geo_zone_id = tr.tax_zone_id)" .
                              " WHERE (za.zone_country_id IS NULL OR za.zone_country_id = '0' OR za.zone_country_id = '" . (int)STORE_COUNTRY . "')" .
                              " AND (za.zone_id IS NULL OR za.zone_id = '0' or za.zone_id = '" . (int)STORE_ZONE . "')" .
                              " AND tr.tax_class_id = '" . (int)$class_id . "'" .
                              " GROUP BY tr.tax_priority");
    if (tep_db_num_rows($tax_query)) {
      $tax_multiplier = 1.0;
      while ($tax = tep_db_fetch_array($tax_query))
        $tax_multiplier *= 1.0 + ($tax['tax_rate'] / 100);
      return ($tax_multiplier - 1.0) * 100;
    } else
      return 0;
  }

/**
 * Get the tax class id knowing a tax rate. Selects the first corresponding value
 * 
 * @param	double	$tax_rate	a tax rate
 * @return	int		a tax class id, or 0 if not found
 */
function opensi_get_tax_class_id($tax_rate) {
	$class_id_query = tep_db_query("SELECT tax_class_id, tax_rate FROM " . TABLE_TAX_RATES);
	while ($class_id = tep_db_fetch_array($class_id_query))
		if ($class_id['tax_rate'] == $tax_rate)
			return $class_id['tax_class_id'];
	
	return 0; // no tax class id
}
 
function tep_not_null($value) {
    if (is_array($value)) {
      if (sizeof($value) > 0) {
        return true;
      } else {
        return false;
      }
    } else {
      if (($value != '') && (strtolower($value) != 'null') && (strlen(trim($value)) > 0)) {
        return true;
      } else {
        return false;
      }
   }
}

/**
 * Gets the number of rows affected by a query (insert, update or delete query)
 * 
 * @param	string		$link	the name of the connection link
 * @return 	int		the number of affected rows
 */
function tep_db_affected_rows($link = 'web_link') {
	global $web_link;
	return mysql_affected_rows($$link);
}

/**
 * Fetches a result in an array
 * 
 * @param	mysql resource	$query	a resource result from mysql_query
 * @return	an array numerically indexed for a row
 */
function tep_db_fetch_row($query) {
	return mysql_fetch_row($query);
}

/**
 * Build an OpenSI article identifier
 * 
 * @param	int		$product_id	OsCommerce product identifier
 * @return	string	An OpenSI article identifier
 */
function build_article_id($product_id) {
	return PRODUCT_ID_PREFIX . $product_id;	
}

/**
 * Extract an OsCommerce product id from an OpenSI article identifier
 * 
 * @param	string	$article_id	OpenSI article identifier
 * @return	int		An OsCommerce product identifier
 */
function extract_product_id($article_id) {
	$id = substr($article_id, strlen(PRODUCT_ID_PREFIX));
	return ($id ? $id : 0);	
}

/**
 * Format a datetime from iso format 'yyyy-mm-dd hh:mm:ss' to 'dd/mm/yyyy/hh/mm'
 * 
 * @param	string	$raw_date	a datetime in iso format
 * @return	string	a date in dd/mm/yyyy/hh/mm format
 */
function opensi_datetime($raw_date) {
	$year = substr($raw_date, 0, 4);
    $month = (int)substr($raw_date, 5, 2);
    $day = (int)substr($raw_date, 8, 2);
    $hour = (int)substr($raw_date, 11, 2);
    $minute = (int)substr($raw_date, 14, 2);
    $second = (int)substr($raw_date, 17, 2);

    if (@date('Y', mktime($hour, $minute, $second, $month, $day, $year)) == $year) {
      return date('d/m/Y/H/i', mktime($hour, $minute, $second, $month, $day, $year));
    } else {
      return ereg_replace('2037' . '$', $year, date('d/m/Y/H/i', mktime($hour, $minute, $second, $month, $day, 2037)));
    }
}

/**
 * Calculate the included tax value
 * 
 * @param	double	$price		excluded tax price
 * @param	double	$tax_rate	tax rate
 * @return	double	included tax price
 */
function calculate_included_tax_price($price, $tax_rate) {
	return round($price + $price * $tax_rate / 100, 2);
}

/**
 * Encode a string in utf-8
 * 
 * @param 	string	$s a string to encode
 * @return	string	encoded string in UTF-8
 */
function opensi_soap_encode($s) {
	$enc = mb_detect_encoding($s);
	if ($enc == 'UTF-8')
		return $s;
	return utf8_encode($s);
}

/**
 * Decode a string from utf-8
 * 
 * @param 	string	$s a string to decode
 * @return	string	decoded string in latin1
 */
function opensi_soap_decode($s) {
	$enc = mb_detect_encoding($s);
	if ($enc == 'UTF-8')
		return utf8_decode($s);
	return $s;
}
?>
